{% load qrcode2 %}

<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>Title</title>
</head>
<body>

<img src="{{ "http://www.baidu.com" | qrcode_src }}">

{% include 'qrcode2/img.html' with text='http://ip138.com' %}

</body>
</html>